==> ij-segment-wrapper-1.13.0.tgz: package/lib/infojobsVisitor/CookieRepository.js <==
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
var IJ_VISITOR_COOKIE_NAME = 'IJ_MCMID';
var ONE_YEAR = 365;

var _setCookie = /*#__PURE__*/_classPrivateFieldLooseKey("setCookie");

var _domainName = /*#__PURE__*/_classPrivateFieldLooseKey("domainName");

export var InfojobsVisitorIdCookieRepository = /*#__PURE__*/function () {
  function InfojobsVisitorIdCookieRepository(_ref) {
    var getCookie = _ref.getCookie,
        setCookie = _ref.setCookie,
        domainName = _ref.domainName;
    Object.defineProperty(this, _setCookie, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _domainName, {
      writable: true,
      value: void 0
    });
    this._getCookie = getCookie;
    _classPrivateFieldLooseBase(this, _setCookie)[_setCookie] = setCookie;
    _classPrivateFieldLooseBase(this, _domainName)[_domainName] = domainName;
  }

  var _proto = InfojobsVisitorIdCookieRepository.prototype;

  _proto.get = function get() {
    return this._getCookie(IJ_VISITOR_COOKIE_NAME);
  };

  _proto.set = function set(_ref2) {
    var visitorId = _ref2.visitorId;

    _classPrivateFieldLooseBase(this, _setCookie)[_setCookie](IJ_VISITOR_COOKIE_NAME, visitorId, {
      expires: ONE_YEAR,
      domain: _classPrivateFieldLooseBase(this, _domainName)[_domainName]
    });
  };

  return InfojobsVisitorIdCookieRepository;
}();

==> ij-segment-wrapper-2.1.0.tgz: package/lib/infojobsVisitor/CookieRepository.js <==
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
var IJ_VISITOR_COOKIE_NAME = 'IJ_MCMID';
var ONE_YEAR = 365;

var _setCookie = /*#__PURE__*/_classPrivateFieldLooseKey("setCookie");

var _getCookie = /*#__PURE__*/_classPrivateFieldLooseKey("getCookie");

var _domainName = /*#__PURE__*/_classPrivateFieldLooseKey("domainName");

var _currentValue = /*#__PURE__*/_classPrivateFieldLooseKey("currentValue");

export var InfojobsVisitorIdCookieRepository = /*#__PURE__*/function () {
  function InfojobsVisitorIdCookieRepository(_ref) {
    var getCookie = _ref.getCookie,
        setCookie = _ref.setCookie,
        domainName = _ref.domainName;
    Object.defineProperty(this, _setCookie, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _getCookie, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _domainName, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _currentValue, {
      writable: true,
      value: void 0
    });
    _classPrivateFieldLooseBase(this, _getCookie)[_getCookie] = getCookie;
    _classPrivateFieldLooseBase(this, _setCookie)[_setCookie] = setCookie;
    _classPrivateFieldLooseBase(this, _domainName)[_domainName] = domainName;
  }

  var _proto = InfojobsVisitorIdCookieRepository.prototype;

  _proto.get = function get() {
    if (_classPrivateFieldLooseBase(this, _currentValue)[_currentValue]) return _classPrivateFieldLooseBase(this, _currentValue)[_currentValue];
    return _classPrivateFieldLooseBase(this, _getCookie)[_getCookie](IJ_VISITOR_COOKIE_NAME);
  };

  _proto.set = function set(_ref2) {
    var visitorId = _ref2.visitorId;
    _classPrivateFieldLooseBase(this, _currentValue)[_currentValue] = visitorId;

    _classPrivateFieldLooseBase(this, _setCookie)[_setCookie](IJ_VISITOR_COOKIE_NAME, visitorId, {
      expires: ONE_YEAR,
      domain: _classPrivateFieldLooseBase(this, _domainName)[_domainName]
    });
  };

  return InfojobsVisitorIdCookieRepository;
}();
